@@ -38,7 +38,7 @@ sub canonicalize {
 sub clone {
   my $self = shift;
 
-  my $clone = Mojo::Path->new->charset($self->charset);
+  my $clone = $self->new->charset($self->charset);
   if (my $parts = $self->{parts}) {
     $clone->{$_} = $self->{$_} for qw(leading_slash trailing_slash);
     $clone->{parts} = [@$parts];
