@@ -180,7 +180,7 @@ sub _cleanup {
   # Clean up active connections (by closing them)
   $self->_handle($_ => 1) for keys %{$self->{connections} || {}};
 
-  # Clean up keep alive connections
+  # Clean up keep-alive connections
   $loop->remove($_->[1]) for @{delete $self->{cache} || []};
 
   # Stop server
@@ -392,7 +392,7 @@ sub _remove {
 
   # Keep connection alive
   $self->_cache(join(':', $self->transactor->endpoint($tx)), $id)
-    unless $tx->req->method eq 'CONNECT' && ($tx->res->code // '') eq '200';
+    unless uc $tx->req->method eq 'CONNECT' && ($tx->res->code // '') eq '200';
 }
 
 sub _redirect {
@@ -590,7 +590,8 @@ Mojo::UserAgent - Non-blocking I/O HTTP and WebSocket user agent
 =head1 DESCRIPTION
 
 L<Mojo::UserAgent> is a full featured non-blocking I/O HTTP and WebSocket user
-agent, with C<IPv6>, C<TLS>, C<SNI>, C<IDNA>, C<Comet> (long polling), C<gzip>
+agent, with C<IPv6>, C<TLS>, C<SNI>, C<IDNA>, C<Comet> (long polling),
+C<keep-alive>, connection pooling, timeout, cookie, multipart, proxy, C<gzip>
 compression and multiple event loop support.
 
 Optional modules L<EV> (4.0+), L<IO::Socket::IP> (0.16+) and
@@ -730,7 +731,7 @@ Local address to bind to.
   my $max = $ua->max_connections;
   $ua     = $ua->max_connections(5);
 
-Maximum number of keep alive connections that the user agent will retain
+Maximum number of keep-alive connections that the user agent will retain
 before it starts closing the oldest cached ones, defaults to C<5>.
 
 =head2 max_redirects
@@ -813,18 +814,18 @@ Get absolute L<Mojo::URL> object for C<app> and switch protocol if necessary.
 
 =head2 build_tx
 
-  my $tx = $ua->build_tx(GET => 'kraih.com');
-  my $tx = $ua->build_tx(PUT => 'http://kraih.com' => {DNT => 1} => 'Hi!');
+  my $tx = $ua->build_tx(GET => 'example.com');
+  my $tx = $ua->build_tx(PUT => 'http://example.com' => {DNT => 1} => 'Hi!');
   my $tx = $ua->build_tx(
-    PUT => 'http://kraih.com' => {DNT => 1} => form => {a => 'b'});
+    PUT => 'http://example.com' => {DNT => 1} => form => {a => 'b'});
   my $tx = $ua->build_tx(
-    PUT => 'http://kraih.com' => {DNT => 1} => json => {a => 'b'});
+    PUT => 'http://example.com' => {DNT => 1} => json => {a => 'b'});
 
 Generate L<Mojo::Transaction::HTTP> object with
 L<Mojo::UserAgent::Transactor/"tx">.
 
   # Request with cookie
-  my $tx = $ua->build_tx(GET => 'kraih.com');
+  my $tx = $ua->build_tx(GET => 'example.com');
   $tx->req->cookies({name => 'foo', value => 'bar'});
   $ua->start($tx);
 
@@ -838,19 +839,19 @@ L<Mojo::UserAgent::Transactor/"websocket">.
 
 =head2 delete
 
-  my $tx = $ua->delete('kraih.com');
-  my $tx = $ua->delete('http://kraih.com' => {DNT => 1} => 'Hi!');
+  my $tx = $ua->delete('example.com');
+  my $tx = $ua->delete('http://example.com' => {DNT => 1} => 'Hi!');
   my $tx = $ua->delete(
-    'http://kraih.com' => {DNT => 1} => form => {a => 'b'});
+    'http://example.com' => {DNT => 1} => form => {a => 'b'});
   my $tx = $ua->delete(
-    'http://kraih.com' => {DNT => 1} => json => {a => 'b'});
+    'http://example.com' => {DNT => 1} => json => {a => 'b'});
 
 Perform blocking HTTP C<DELETE> request and return resulting
 L<Mojo::Transaction::HTTP> object, takes the same arguments as
 L<Mojo::UserAgent::Transactor/"tx"> (except for the method). You can also
 append a callback to perform requests non-blocking.
 
-  $ua->delete('http://kraih.com' => sub {
+  $ua->delete('http://example.com' => sub {
     my ($ua, $tx) = @_;
     say $tx->res->body;
   });
@@ -866,17 +867,17 @@ enabled with the MOJO_PROXY environment variable.
 
 =head2 get
 
-  my $tx = $ua->get('kraih.com');
-  my $tx = $ua->get('http://kraih.com' => {DNT => 1} => 'Hi!');
-  my $tx = $ua->get('http://kraih.com' => {DNT => 1} => form => {a => 'b'});
-  my $tx = $ua->get('http://kraih.com' => {DNT => 1} => json => {a => 'b'});
+  my $tx = $ua->get('example.com');
+  my $tx = $ua->get('http://example.com' => {DNT => 1} => 'Hi!');
+  my $tx = $ua->get('http://example.com' => {DNT => 1} => form => {a => 'b'});
+  my $tx = $ua->get('http://example.com' => {DNT => 1} => json => {a => 'b'});
 
 Perform blocking HTTP C<GET> request and return resulting
 L<Mojo::Transaction::HTTP> object, takes the same arguments as
 L<Mojo::UserAgent::Transactor/"tx"> (except for the method). You can also
 append a callback to perform requests non-blocking.
 
-  $ua->get('http://kraih.com' => sub {
+  $ua->get('http://example.com' => sub {
     my ($ua, $tx) = @_;
     say $tx->res->body;
   });
@@ -884,17 +885,19 @@ append a callback to perform requests non-blocking.
 
 =head2 head
 
-  my $tx = $ua->head('kraih.com');
-  my $tx = $ua->head('http://kraih.com' => {DNT => 1} => 'Hi!');
-  my $tx = $ua->head('http://kraih.com' => {DNT => 1} => form => {a => 'b'});
-  my $tx = $ua->head('http://kraih.com' => {DNT => 1} => json => {a => 'b'});
+  my $tx = $ua->head('example.com');
+  my $tx = $ua->head('http://example.com' => {DNT => 1} => 'Hi!');
+  my $tx = $ua->head(
+    'http://example.com' => {DNT => 1} => form => {a => 'b'});
+  my $tx = $ua->head(
+    'http://example.com' => {DNT => 1} => json => {a => 'b'});
 
 Perform blocking HTTP C<HEAD> request and return resulting
 L<Mojo::Transaction::HTTP> object, takes the same arguments as
 L<Mojo::UserAgent::Transactor/"tx"> (except for the method). You can also
 append a callback to perform requests non-blocking.
 
-  $ua->head('http://kraih.com' => sub {
+  $ua->head('http://example.com' => sub {
     my ($ua, $tx) = @_;
     say $tx->res->body;
   });
@@ -908,19 +911,19 @@ Check if request for domain would use a proxy server.
 
 =head2 options
 
-  my $tx = $ua->options('kraih.com');
-  my $tx = $ua->options('http://kraih.com' => {DNT => 1} => 'Hi!');
+  my $tx = $ua->options('example.com');
+  my $tx = $ua->options('http://example.com' => {DNT => 1} => 'Hi!');
   my $tx = $ua->options(
-    'http://kraih.com' => {DNT => 1} => form => {a => 'b'});
+    'http://example.com' => {DNT => 1} => form => {a => 'b'});
   my $tx = $ua->options(
-    'http://kraih.com' => {DNT => 1} => json => {a => 'b'});
+    'http://example.com' => {DNT => 1} => json => {a => 'b'});
 
 Perform blocking HTTP C<OPTIONS> request and return resulting
 L<Mojo::Transaction::HTTP> object, takes the same arguments as
 L<Mojo::UserAgent::Transactor/"tx"> (except for the method). You can also
 append a callback to perform requests non-blocking.
 
-  $ua->options('http://kraih.com' => sub {
+  $ua->options('http://example.com' => sub {
     my ($ua, $tx) = @_;
     say $tx->res->body;
   });
@@ -928,17 +931,19 @@ append a callback to perform requests non-blocking.
 
 =head2 patch
 
-  my $tx = $ua->patch('kraih.com');
-  my $tx = $ua->patch('http://kraih.com' => {DNT => 1} => 'Hi!');
-  my $tx = $ua->patch('http://kraih.com' => {DNT => 1} => form => {a => 'b'});
-  my $tx = $ua->patch('http://kraih.com' => {DNT => 1} => json => {a => 'b'});
+  my $tx = $ua->patch('example.com');
+  my $tx = $ua->patch('http://example.com' => {DNT => 1} => 'Hi!');
+  my $tx = $ua->patch(
+    'http://example.com' => {DNT => 1} => form => {a => 'b'});
+  my $tx = $ua->patch(
+    'http://example.com' => {DNT => 1} => json => {a => 'b'});
 
 Perform blocking HTTP C<PATCH> request and return resulting
 L<Mojo::Transaction::HTTP> object, takes the same arguments as
 L<Mojo::UserAgent::Transactor/"tx"> (except for the method). You can also
 append a callback to perform requests non-blocking.
 
-  $ua->patch('http://kraih.com' => sub {
+  $ua->patch('http://example.com' => sub {
     my ($ua, $tx) = @_;
     say $tx->res->body;
   });
@@ -946,17 +951,19 @@ append a callback to perform requests non-blocking.
 
 =head2 post
 
-  my $tx = $ua->post('kraih.com');
-  my $tx = $ua->post('http://kraih.com' => {DNT => 1} => 'Hi!');
-  my $tx = $ua->post('http://kraih.com' => {DNT => 1} => form => {a => 'b'});
-  my $tx = $ua->post('http://kraih.com' => {DNT => 1} => json => {a => 'b'});
+  my $tx = $ua->post('example.com');
+  my $tx = $ua->post('http://example.com' => {DNT => 1} => 'Hi!');
+  my $tx = $ua->post(
+    'http://example.com' => {DNT => 1} => form => {a => 'b'});
+  my $tx = $ua->post(
+    'http://example.com' => {DNT => 1} => json => {a => 'b'});
 
 Perform blocking HTTP C<POST> request and return resulting
 L<Mojo::Transaction::HTTP> object, takes the same arguments as
 L<Mojo::UserAgent::Transactor/"tx"> (except for the method). You can also
 append a callback to perform requests non-blocking.
 
-  $ua->post('http://kraih.com' => sub {
+  $ua->post('http://example.com' => sub {
     my ($ua, $tx) = @_;
     say $tx->res->body;
   });
@@ -964,17 +971,17 @@ append a callback to perform requests non-blocking.
 
 =head2 put
 
-  my $tx = $ua->put('kraih.com');
-  my $tx = $ua->put('http://kraih.com' => {DNT => 1} => 'Hi!');
-  my $tx = $ua->put('http://kraih.com' => {DNT => 1} => form => {a => 'b'});
-  my $tx = $ua->put('http://kraih.com' => {DNT => 1} => json => {a => 'b'});
+  my $tx = $ua->put('example.com');
+  my $tx = $ua->put('http://example.com' => {DNT => 1} => 'Hi!');
+  my $tx = $ua->put('http://example.com' => {DNT => 1} => form => {a => 'b'});
+  my $tx = $ua->put('http://example.com' => {DNT => 1} => json => {a => 'b'});
 
 Perform blocking HTTP C<PUT> request and return resulting
 L<Mojo::Transaction::HTTP> object, takes the same arguments as
 L<Mojo::UserAgent::Transactor/"tx"> (except for the method). You can also
 append a callback to perform requests non-blocking.
 
-  $ua->put('http://kraih.com' => sub {
+  $ua->put('http://example.com' => sub {
     my ($ua, $tx) = @_;
     say $tx->res->body;
   });
@@ -987,7 +994,7 @@ append a callback to perform requests non-blocking.
 Perform blocking request. You can also append a callback to perform requests
 non-blocking.
 
-  my $tx = $ua->build_tx(GET => 'http://kraih.com');
+  my $tx = $ua->build_tx(GET => 'http://example.com');
   $ua->start($tx => sub {
     my ($ua, $tx) = @_;
     say $tx->res->body;
