@@ -37,11 +37,11 @@ sub load_plugin {
   my $class = $name =~ /^[a-z]/ ? camelize($name) : $name;
   for my $namespace (@{$self->namespaces}) {
     my $module = "${namespace}::$class";
-    return $module->new if $self->_load($module);
+    return $module->new if _load($module);
   }
 
   # Full module name
-  return $name->new if $self->_load($name);
+  return $name->new if _load($name);
 
   # Not found
   die qq{Plugin "$name" missing, maybe you need to install it?\n};
@@ -52,14 +52,10 @@ sub register_plugin {
 }
 
 sub _load {
-  my ($self, $module) = @_;
-
-  # Load
+  my $module = shift;
   if (my $e = Mojo::Loader->new->load($module)) {
     ref $e ? die $e : return undef;
   }
-
-  # Module is a plugin
   return $module->isa('Mojolicious::Plugin') ? 1 : undef;
 }
 
